pub struct SfcStyle {
pub body: String,
pub lang: Option<String>,
pub src: Option<String>,
pub src_span: Option<Span>,
pub byte_offset: usize,
}Expand description
An extracted <style> block from a Vue or Svelte SFC.
Fields
body: StringThe style body text (CSS / SCSS / Sass / Less / Stylus / PostCSS source).
lang: Option<String>The lang attribute value (scss, sass, less, stylus, postcss, …).
None for plain <style> (CSS).
src: Option<String>External style source path from the src attribute (<style src="./theme.scss">).
src_span: Option<Span>Span of the src attribute value in the full SFC source.
byte_offset: usizeByte offset of the style body within the full SFC source.