CSS/SCSS file parsing and CSS Module class name extraction.
Handles @import, @use, @forward, @apply, @tailwind directives,
and extracts class names as named exports from .module.css/.module.scss files.
Structs
- CssImport
Source - A CSS import source with both the literal source and fallow’s resolver-normalized form.
Functions
- extract_
css_ import_ sources - Extract
@import/@use/@forwardsource paths from a CSS/SCSS string. - extract_
css_ imports - Extract normalized
@import/@use/@forwardsource paths from a CSS/SCSS string. - extract_
css_ module_ exports - Extract class names from a CSS module file as named exports.