Module html

Module html 

HTML file parsing for script and stylesheet asset references.

Extracts <script src="..."> and <link rel="stylesheet" href="..."> references from HTML files, creating graph edges so that referenced JS/CSS assets (and their transitive imports) are reachable from the HTML entry point.